"use strict";
//
// Copyright 2023 Signal Messenger, LLC.
// SPDX-License-Identifier: AGPL-3.0-only
//
Object.defineProperty(exports, "__esModule", { value: true });
exports.sanitize = void 0;
/**
 * A WebP format “sanitizer”.
 *
 * The sanitizer currently simply checks the validity of a WebP file input, so that passing a malformed file to an
 * unsafe parser can be avoided.
 *
 * @module WebpSanitizer
 */
const Native = require("../Native");
/**
 * Sanitize a WebP input.
 *
 * @param input A WebP format input stream.
 * @throws {IoError} If an IO error on the input occurs.
 * @throws {InvalidMediaInputError} If the input could not be parsed because it was invalid.
 * @throws {UnsupportedMediaInputError} If the input could not be parsed because it's unsupported in some way.
 */
function sanitize(input) {
    Native.WebpSanitizer_Sanitize(input);
}
exports.sanitize = sanitize;
//# sourceMappingURL=WebpSanitizer.js.map