"use strict";
//
// Copyright 2023 Signal Messenger, LLC.
// SPDX-License-Identifier: AGPL-3.0-only
//
Object.defineProperty(exports, "__esModule", { value: true });
const uuid = require("uuid");
const ByteArray_1 = require("../internal/ByteArray");
const Native = require("../../../Native");
const BackupAuthCredentialRequest_1 = require("./BackupAuthCredentialRequest");
const BackupAuthCredential_1 = require("./BackupAuthCredential");
class BackupAuthCredentialRequestContext extends ByteArray_1.default {
    constructor(contents) {
        super(contents, Native.BackupAuthCredentialRequestContext_CheckValidContents);
    }
    static create(backupKey, aci) {
        return new BackupAuthCredentialRequestContext(Native.BackupAuthCredentialRequestContext_New(backupKey, Buffer.from(uuid.parse(aci))));
    }
    getRequest() {
        return new BackupAuthCredentialRequest_1.default(Native.BackupAuthCredentialRequestContext_GetRequest(this.contents));
    }
    receive(response, redemptionTime, params) {
        return new BackupAuthCredential_1.default(Native.BackupAuthCredentialRequestContext_ReceiveResponse(this.contents, response.contents, redemptionTime, params.contents));
    }
}
exports.default = BackupAuthCredentialRequestContext;
//# sourceMappingURL=BackupAuthCredentialRequestContext.js.map